@@ -58,7 +58,7 @@ SWSUSP_D="/etc/hibernate"
 SCRIPTLET_PATH="$SWSUSP_D/scriptlets.d /usr/local/share/hibernate/scriptlets.d /usr/share/hibernate/scriptlets.d"
 DEFAULT_CONFIG_FILE="$SWSUSP_D/hibernate.conf"
 EXE="${0##*/}"
-VERSION="1.97"
+VERSION="1.99"
 
 # Add these to the $PATH just in case.
 PATH="$PATH:/sbin:/usr/sbin:/usr/local/sbin"
@@ -222,8 +222,8 @@ FindXServer() {
 	    # Ensure the process still exists, and we aren't hallucinating.
 	    [ -d "/proc/$xpid/" ] || continue
 
-	    xauth="`get_env_var_of_process XAUTHORITY $xpid`"
-	    xhome="`get_env_var_of_process HOME $xpid`"
+	    xauth="`get_env_var_of_process $xpid XAUTHORITY`"
+	    xhome="`get_env_var_of_process $xpid HOME`"
 	    xuser=`/bin/ls -ld /proc/$xpid/ | awk '{print $3}'`
 	    [ -z $xauth ] && [ -n $xhome ] && [ -f $xhome/.Xauthority ] && xauth=$xhome/.Xauthority
 
@@ -389,10 +389,20 @@ EnsureHavePrerequisites() {
 	    local CNT
 	    local D
 	    local FN
+	    local RND1
+	    local RND2
 	    CNT=1
+	    if [ -z "$RANDOM" ] ; then
+	    	# A fix for shells that do not have this bash feature
+		RND1=$(dd if=/dev/urandom count=1 2>/dev/null|cksum|cut -c"1-5")
+		RND2=$(dd if=/dev/urandom count=1 2>/dev/null|cksum|cut -c"1-5")
+	    else
+	        RND1=$RANDOM
+		RND2=$RANDOM
+	    fi
 	    while true ; do
 		D=`date +%s`
-		FN=/tmp/tmp.hibernate.$$$D$RANDOM$RANDOM$CNT
+		FN=/tmp/tmp.hibernate.$$$D$RND1$RND2$CNT
 		[ -f $FN ] && continue
 		touch $FN && break
 		CNT=$(($CNT+1))
@@ -690,7 +700,7 @@ ProcessConfigOption() {
 conffiles_read=
 ReadConfigFile() {
     local option params
-    local file_name="$1"
+    local file_name; file_name="$1"
     
     if [ ! -f "${file_name}" ] ; then
 	# Search in /etc/hibernate
@@ -822,7 +832,8 @@ ctrlc_handler() {
 # processes identified by its PID.
 get_env_var_of_process()
 {
-    local pid="$1" envvar="$2"
+    local pid; pid="$1"
+    local envvar; envvar="$2"
     tr '\0' '\n' </proc/$pid/environ | sed -ne "s/^$envvar=//p"
 }
 
@@ -904,4 +915,4 @@ echo "Resumed at "`date` | $LOGPIPE > /dev/null
 
 exit $EXIT_CODE
 
-# $Id: hibernate.sh 1155 2007-09-30 13:54:58Z madduck $
+# $Id: hibernate.sh 1196 2008-05-01 11:58:52Z nigel $
