@@ -6,6 +6,7 @@
 [ -z "$EXEC_PREFIX" ]   	&& EXEC_PREFIX=$PREFIX
 
 [ -z "$SCRIPT_DEST" ]   	&& SCRIPT_DEST=$BASE_DIR$EXEC_PREFIX/sbin/hibernate
+[ -z "$SHARE_DIR" ] 		&& SHARE_DIR=$BASE_DIR$PREFIX/share/hibernate
 [ -z "$SCRIPTLET_DIR" ] 	&& SCRIPTLET_DIR=$BASE_DIR$PREFIX/share/hibernate/scriptlets.d
 [ -z "$MAN_DIR" ]       	&& MAN_DIR=$BASE_DIR$PREFIX/man
 [ -z "$CONFIG_DIR" ]    	&& CONFIG_DIR=${BASE_DIR}${CONFIG_PREFIX}/etc/hibernate
@@ -78,6 +79,9 @@ for i in scriptlets.d/* ; do
     cp -a $i $SCRIPTLET_DIR
 done
 
+echo "Installing sample binary signature to $SHARE_DIR ..."
+cp -a tuxonice-binary-signature.bin $SHARE_DIR
+
 if [ -d "$LOGROTATE_DIR" ] ; then
     LOGROTATE_TARGET=$LOGROTATE_DIR/hibernate-script
     echo "Installing logrotate file for hibernate.log to $LOGROTATE_TARGET ..."
@@ -117,4 +121,4 @@ fi
 
 exit 0
 
-# $Id: install.sh 1109 2007-05-26 14:41:11Z bernard $
+# $Id: install.sh 1196 2008-05-01 11:58:52Z nigel $
